@@ -234,7 +234,6 @@ class RecipeReader:
 
 from gensim.models import Word2Vec
 from sentence_transformers import SentenceTransformer
-from annoy import AnnoyIndex
 import pandas as pd
 from ..data.embeddings import mean_ing_embedding
 from qdrant_client import QdrantClient
@@ -257,14 +256,6 @@ class TagReader:
         self.tags = list(self.__mean_ing_e_per_tag.columns)
         self.__mean_ing_e = np.array(mean_ing_embedding)
 
-        self.__tags_index = AnnoyIndex(TAG_EMBEDDING_LEN, "angular")
-        embedded_tags = self.tag_model.encode(self.tags)
-
-        for id, tag_embedding in enumerate(list(embedded_tags)):
-            self.__tags_index.add_item(id, tag_embedding)
-
-        self.__tags_index.build(10)
-
         self.qdrant = QdrantClient(host="qdrant.pocketsomm.dev", port=443, https=True)
 
     def generate_ing_embedding(self, ing):
@@ -290,11 +281,13 @@ class TagReader:
         return np.add(embedding_sum, self.__mean_ing_e)
 
     def get_closest_tag(self, tag):
-        index = self.__tags_index.get_nns_by_vector(
-            self.generate_tag_embedding(tag), 1
-        )[0]
-
-        return self.tags[index]
+        return self.qdrant.search(
+            collection_name=f"tag",
+            query_vector=self.tag_model.encode(tag),
+            limit=1,
+            # with_vectors=True,
+            with_payload=True,
+        )[0].payload["value"]
 
     def read(self, tags):
         embedding = self.get_ing_embedding_by_tags(tags)
@@ -306,7 +299,7 @@ class TagReader:
             with_payload=True,
         )[0]
 
-        values = search_result.vector["oneHot"]
+        values = np.array(search_result.vector["oneHot"])
         mask = values != 0
         values[mask] = 1.0
 
